"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    instance_id: str,
    integration_association_id: str,
    use_case_type: str,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a use case for an AppIntegration association.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        integration_association_id(str): The identifier for the AppIntegration association.
        use_case_type(str): The type of use case to associate to the AppIntegration association. Each AppIntegration association can have only one of each use case type.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.use.case.create(
                ctx, instance_id=value, integration_association_id=value, use_case_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.use.case.create instance_id=value, integration_association_id=value, use_case_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_use_case",
        op_kwargs={
            "InstanceId": instance_id,
            "IntegrationAssociationId": integration_association_id,
            "UseCaseType": use_case_type,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, instance_id: str, integration_association_id: str, use_case_id: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes a use case from an AppIntegration association.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        integration_association_id(str): The identifier for the AppIntegration association.
        use_case_id(str): The identifier for the use case.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.use.case.delete(
                ctx, instance_id=value, integration_association_id=value, use_case_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.use.case.delete instance_id=value, integration_association_id=value, use_case_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_use_case",
        op_kwargs={
            "InstanceId": instance_id,
            "IntegrationAssociationId": integration_association_id,
            "UseCaseId": use_case_id,
        },
    )


async def list_all(
    hub,
    ctx,
    instance_id: str,
    integration_association_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the use cases.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        integration_association_id(str): The identifier for the integration association.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.use.case.list_all(
                ctx, instance_id=value, integration_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.use.case.list_all instance_id=value, integration_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_use_cases",
        op_kwargs={
            "InstanceId": instance_id,
            "IntegrationAssociationId": integration_association_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, instance_id: str, queue_id: str, quick_connect_ids: List
) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Associates a set of quick connects with a queue.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        queue_id(str): The identifier for the queue.
        quick_connect_ids(List): The quick connects to associate with this queue.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.queue.quick_connect.associate(
                ctx, instance_id=value, queue_id=value, quick_connect_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.queue.quick_connect.associate instance_id=value, queue_id=value, quick_connect_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="associate_queue_quick_connects",
        op_kwargs={
            "InstanceId": instance_id,
            "QueueId": queue_id,
            "QuickConnectIds": quick_connect_ids,
        },
    )


async def disassociate(
    hub, ctx, instance_id: str, queue_id: str, quick_connect_ids: List
) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Disassociates a set of quick connects from a queue.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        queue_id(str): The identifier for the queue.
        quick_connect_ids(List): The quick connects to disassociate from the queue.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.queue.quick_connect.disassociate(
                ctx, instance_id=value, queue_id=value, quick_connect_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.queue.quick_connect.disassociate instance_id=value, queue_id=value, quick_connect_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="disassociate_queue_quick_connects",
        op_kwargs={
            "InstanceId": instance_id,
            "QueueId": queue_id,
            "QuickConnectIds": quick_connect_ids,
        },
    )


async def list_all(
    hub,
    ctx,
    instance_id: str,
    queue_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Lists the quick connects associated with a queue.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        queue_id(str): The identifier for the queue.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.queue.quick_connect.list_all(
                ctx, instance_id=value, queue_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.queue.quick_connect.list_all instance_id=value, queue_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_queue_quick_connects",
        op_kwargs={
            "InstanceId": instance_id,
            "QueueId": queue_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, pull_request_id: str, description: str) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the contents of the description of a pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        description(str): The updated content of the description for the pull request. This content replaces the existing description.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.description.update(
                ctx, pull_request_id=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.description.update pull_request_id=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_pull_request_description",
        op_kwargs={"pullRequestId": pull_request_id, "description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(
    hub,
    ctx,
    document_name: str,
    runbooks: List,
    scheduled_time: str = None,
    document_version: str = None,
    parameters: Dict = None,
    change_request_name: str = None,
    client_token: str = None,
    tags: List = None,
    scheduled_end_time: str = None,
    change_details: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a change request for Change Manager. The Automation runbooks specified in the change request run only after all required approvals for the change request have been received.

    Args:
        scheduled_time(str, optional): The date and time specified in the change request to run the Automation runbooks.  The Automation runbooks specified for the runbook workflow can't run until all required approvals for the change request have been received. . Defaults to None.
        document_name(str): The name of the change template document to run during the runbook workflow.
        document_version(str, optional): The version of the change template document to run during the runbook workflow. Defaults to None.
        parameters(Dict, optional): A key-value map of parameters that match the declared parameters in the change template document. Defaults to None.
        change_request_name(str, optional): The name of the change request associated with the runbook workflow to be run. Defaults to None.
        client_token(str, optional): The user-provided idempotency token. The token must be unique, is case insensitive, enforces the UUID format, and can't be reused. Defaults to None.
        runbooks(List): Information about the Automation runbooks that are run during the runbook workflow.  The Automation runbooks specified for the runbook workflow can't run until all required approvals for the change request have been received. .
        tags(List, optional): Optional metadata that you assign to a resource. You can specify a maximum of five tags for a change request. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag a change request to identify an environment or target Region. In this case, you could specify the following key-value pairs:    Key=Environment,Value=Production     Key=Region,Value=us-east-2   . Defaults to None.
        scheduled_end_time(str, optional): The time that the requester expects the runbook workflow related to the change request to complete. The time is an estimate only that the requester provides for reviewers. Defaults to None.
        change_details(str, optional): User-provided details about the change. If no details are provided, content specified in the Template information section of the associated change template is added. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.change_request_execution.start(
                ctx, document_name=value, runbooks=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.change_request_execution.start document_name=value, runbooks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="start_change_request_execution",
        op_kwargs={
            "ScheduledTime": scheduled_time,
            "DocumentName": document_name,
            "DocumentVersion": document_version,
            "Parameters": parameters,
            "ChangeRequestName": change_request_name,
            "ClientToken": client_token,
            "Runbooks": runbooks,
            "Tags": tags,
            "ScheduledEndTime": scheduled_end_time,
            "ChangeDetails": change_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    retention_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The CreateTable operation adds a new table to an existing database in your account. In an AWS account, table names must be at least unique within each Region if they are in the same database. You may have identical table names in the same Region if the tables are in seperate databases. While creating the table, you must specify the table name, database name, and the retention properties. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.
        table_name(str): The name of the Timestream table.
        retention_properties(Dict, optional): The duration for which your time series data must be stored in the memory store and the magnetic store. Defaults to None.
        tags(List, optional):  A list of key-value pairs to label the table. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.table.create(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.table.create database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="create_table",
        op_kwargs={
            "DatabaseName": database_name,
            "TableName": table_name,
            "RetentionProperties": retention_properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, database_name: str, table_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a given Timestream table. This is an irreversible operation. After a Timestream database table is deleted, the time series data stored in the table cannot be recovered.  Due to the nature of distributed retries, the operation can return either success or a ResourceNotFoundException. Clients should consider them equivalent.

    Args:
        database_name(str): The name of the database where the Timestream database is to be deleted.
        table_name(str): The name of the Timestream table to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.table.delete(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.table.delete database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="delete_table",
        op_kwargs={"DatabaseName": database_name, "TableName": table_name},
    )


async def describe(hub, ctx, database_name: str, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the table, including the table name, database name, retention duration of the memory store and the magnetic store. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.
        table_name(str): The name of the Timestream table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.table.describe(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.table.describe database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="describe_table",
        op_kwargs={"DatabaseName": database_name, "TableName": table_name},
    )


async def list_all(
    hub, ctx, database_name: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    A list of tables, along with the name, status and retention properties of each table.

    Args:
        database_name(str, optional): The name of the Timestream database. Defaults to None.
        next_token(str, optional): The pagination token. To resume pagination, provide the NextToken value as argument of a subsequent API invocation. Defaults to None.
        max_results(int, optional): The total number of items to return in the output. If the total number of items available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as argument of a subsequent API invocation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.table.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.table.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="list_tables",
        op_kwargs={
            "DatabaseName": database_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, database_name: str, table_name: str, retention_properties: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the retention duration of the memory store and magnetic store for your Timestream table. Note that the change in retention duration takes effect immediately. For example, if the retention period of the memory store was initially set to 2 hours and then changed to 24 hours, the memory store will be capable of holding 24 hours of data, but will be populated with 24 hours of data 22 hours after this change was made. Timestream does not retrieve data from the magnetic store to populate the memory store.  Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.
        table_name(str): The name of the Timesream table.
        retention_properties(Dict): The retention duration of the memory store and the magnetic store.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.table.update(
                ctx, database_name=value, table_name=value, retention_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.table.update database_name=value, table_name=value, retention_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="update_table",
        op_kwargs={
            "DatabaseName": database_name,
            "TableName": table_name,
            "RetentionProperties": retention_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, pull_request_id: str, pull_request_status: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status of a pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        pull_request_status(str): The status of the pull request. The only valid operations are to update the status from OPEN to OPEN, OPEN to CLOSED or from CLOSED to CLOSED.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.status.update(
                ctx, pull_request_id=value, pull_request_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.status.update pull_request_id=value, pull_request_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_pull_request_status",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "pullRequestStatus": pull_request_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    auto_create_tasks: bool,
    name: str = None,
    update: Dict = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a gateway task definition.

    Args:
        auto_create_tasks(bool): Whether to automatically create tasks using this task definition for all gateways with the specified current version. If false, the task must me created by calling CreateWirelessGatewayTask.
        name(str, optional): The name of the new resource. Defaults to None.
        update(Dict, optional): Information about the gateways to update. Defaults to None.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.
        tags(List, optional): The tags to attach to the specified resource. Tags are metadata that you can use to manage a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.definition.create(
                ctx, auto_create_tasks=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.definition.create auto_create_tasks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_wireless_gateway_task_definition",
        op_kwargs={
            "AutoCreateTasks": auto_create_tasks,
            "Name": name,
            "Update": update,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a wireless gateway task definition. Deleting this task definition does not affect tasks that are currently in progress.

    Args:
        id_(str): The ID of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.definition.delete(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.definition.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_wireless_gateway_task_definition",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a wireless gateway task definition.

    Args:
        id_(str): The ID of the resource to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.definition.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.definition.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_gateway_task_definition",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    task_definition_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the wireless gateway tasks definitions registered to your AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        task_definition_type(str, optional): A filter to list only the wireless gateway task definitions that use this task definition type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.task.definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.task.definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_wireless_gateway_task_definitions",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "TaskDefinitionType": task_definition_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def generate(
    hub,
    ctx,
    key_id: str,
    encryption_context: Dict = None,
    key_spec: str = None,
    number_of_bytes: int = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a unique symmetric data key. This operation returns a data key that is encrypted under a customer master key (CMK) that you specify. To request an asymmetric data key pair, use the GenerateDataKeyPair or GenerateDataKeyPairWithoutPlaintext operations.  GenerateDataKeyWithoutPlaintext is identical to the GenerateDataKey operation except that returns only the encrypted copy of the data key. This operation is useful for systems that need to encrypt data at some point, but not immediately. When you need to encrypt the data, you call the Decrypt operation on the encrypted copy of the key.  It's also useful in distributed systems with different levels of trust. For example, you might store encrypted data in containers. One component of your system creates new containers and stores an encrypted data key with each container. Then, a different component puts the data into the containers. That component first decrypts the data key, uses the plaintext data key to encrypt data, puts the encrypted data into the container, and then destroys the plaintext data key. In this system, the component that creates the containers never sees the plaintext data key.  GenerateDataKeyWithoutPlaintext returns a unique data key for each request. The bytes in the keys are not related to the caller or CMK that is used to encrypt the private key. To generate a data key, you must specify the symmetric customer master key (CMK) that is used to encrypt the data key. You cannot use an asymmetric CMK to generate a data key. To get the type of your CMK, use the DescribeKey operation. If the operation succeeds, you will find the encrypted copy of the data key in the CiphertextBlob field. You can use the optional encryption context to add additional security to the encryption operation. If you specify an EncryptionContext, you must specify the same encryption context (a case-sensitive exact match) when decrypting the encrypted data key. Otherwise, the request to decrypt fails with an InvalidCiphertextException. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:GenerateDataKeyWithoutPlaintext (key policy)  Related operations:     Decrypt     Encrypt     GenerateDataKey     GenerateDataKeyPair     GenerateDataKeyPairWithoutPlaintext

    Args:
        key_id(str): The identifier of the symmetric customer master key (CMK) that encrypts the data key. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        encryption_context(Dict, optional): Specifies the encryption context that will be used when encrypting the data key. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        key_spec(str, optional): The length of the data key. Use AES_128 to generate a 128-bit symmetric key, or AES_256 to generate a 256-bit symmetric key. Defaults to None.
        number_of_bytes(int, optional): The length of the data key in bytes. For example, use the value 64 to generate a 512-bit data key (64 bytes is 512 bits). For common key lengths (128-bit and 256-bit symmetric keys), we recommend that you use the KeySpec field instead of this one. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.data_key.without_plaintext.generate(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.data_key.without_plaintext.generate key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="generate_data_key_without_plaintext",
        op_kwargs={
            "KeyId": key_id,
            "EncryptionContext": encryption_context,
            "KeySpec": key_spec,
            "NumberOfBytes": number_of_bytes,
            "GrantTokens": grant_tokens,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_index: Dict,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a specified partition index in an existing table.

    Args:
        catalog_id(str, optional): The catalog ID where the table resides. Defaults to None.
        database_name(str): Specifies the name of a database in which you want to create a partition index.
        table_name(str): Specifies the name of a table in which you want to create a partition index.
        partition_index(Dict): Specifies a PartitionIndex structure to create a partition index in an existing table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.index.create(
                ctx, database_name=value, table_name=value, partition_index=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.index.create database_name=value, table_name=value, partition_index=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_partition_index",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionIndex": partition_index,
        },
    )


async def delete(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    index_name: str,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified partition index from an existing table.

    Args:
        catalog_id(str, optional): The catalog ID where the table resides. Defaults to None.
        database_name(str): Specifies the name of a database from which you want to delete a partition index.
        table_name(str): Specifies the name of a table from which you want to delete a partition index.
        index_name(str): The name of the partition index to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.index.delete(
                ctx, database_name=value, table_name=value, index_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.index.delete database_name=value, table_name=value, index_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_partition_index",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "IndexName": index_name,
        },
    )


async def get_all(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    catalog_id: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the partition indexes associated with a table.

    Args:
        catalog_id(str, optional): The catalog ID where the table resides. Defaults to None.
        database_name(str): Specifies the name of a database from which you want to retrieve partition indexes.
        table_name(str): Specifies the name of a table for which you want to retrieve the partition indexes.
        next_token(str, optional): A continuation token, included if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.partition.index.get_all(
                ctx, database_name=value, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.partition.index.get_all database_name=value, table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_partition_indexes",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, server_name: str, description: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates an application-level backup of a server. While the server is in the BACKING_UP state, the server cannot be changed, and no additional backup can be created.   Backups can be created for servers in RUNNING, HEALTHY, and UNHEALTHY states. By default, you can create a maximum of 50 manual backups.   This operation is asynchronous.   A LimitExceededException is thrown when the maximum number of manual backups is reached. An InvalidStateException is thrown when the server is not in any of the following states: RUNNING, HEALTHY, or UNHEALTHY. A ResourceNotFoundException is thrown when the server is not found. A ValidationException is thrown when parameters of the request are not valid.

    Args:
        server_name(str): The name of the server that you want to back up. .
        description(str, optional):  A user-defined description of the backup. . Defaults to None.
        tags(List, optional): A map that contains tag keys and tag values to attach to an AWS OpsWorks-CM server backup.   The key cannot be empty.   The key can be a maximum of 127 characters, and can contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    The value can be a maximum 255 characters, and contain only Unicode letters, numbers, or separators, or the following special characters: + - = . _ : /    Leading and trailing white spaces are trimmed from both the key and value.   A maximum of 50 user-applied tags is allowed for tag-supported AWS OpsWorks-CM resources.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.backup.create(ctx, server_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.backup.create server_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="create_backup",
        op_kwargs={"ServerName": server_name, "Description": description, "Tags": tags},
    )


async def delete(hub, ctx, backup_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a backup. You can delete both manual and automated backups. This operation is asynchronous.   An InvalidStateException is thrown when a backup deletion is already in progress. A ResourceNotFoundException is thrown when the backup does not exist. A ValidationException is thrown when parameters of the request are not valid.

    Args:
        backup_id(str): The ID of the backup to delete. Run the DescribeBackups command to get a list of backup IDs. Backup IDs are in the format ServerName-yyyyMMddHHmmssSSS. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.backup.delete(ctx, backup_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.backup.delete backup_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="delete_backup",
        op_kwargs={"BackupId": backup_id},
    )


async def describe_all(
    hub,
    ctx,
    backup_id: str = None,
    server_name: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Describes backups. The results are ordered by time, with newest backups first. If you do not specify a BackupId or ServerName, the command returns all backups.   This operation is synchronous.   A ResourceNotFoundException is thrown when the backup does not exist. A ValidationException is raised when parameters of the request are not valid.

    Args:
        backup_id(str, optional): Describes a single backup. . Defaults to None.
        server_name(str, optional): Returns backups for the server with the specified ServerName. . Defaults to None.
        next_token(str, optional): This is not currently implemented for DescribeBackups requests. Defaults to None.
        max_results(int, optional): This is not currently implemented for DescribeBackups requests. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.backup.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.backup.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="describe_backups",
        op_kwargs={
            "BackupId": backup_id,
            "ServerName": server_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, transform_id: str, output_s3_path: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts the active learning workflow for your machine learning transform to improve the transform's quality by generating label sets and adding labels. When the StartMLLabelingSetGenerationTaskRun finishes, Glue will have generated a "labeling set" or a set of questions for humans to answer. In the case of the FindMatches transform, these questions are of the form, “What is the correct way to group these rows together into groups composed entirely of matching records?”  After the labeling process is finished, you can upload your labels with a call to StartImportLabelsTaskRun. After StartImportLabelsTaskRun finishes, all future runs of the machine learning transform will use the new and improved labels and perform a higher-quality transformation.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.
        output_s3_path(str): The Amazon Simple Storage Service (Amazon S3) path where you generate the labeling set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.ml.labeling_set_generation_task_run.start(
                ctx, transform_id=value, output_s3_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.ml.labeling_set_generation_task_run.start transform_id=value, output_s3_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="start_ml_labeling_set_generation_task_run",
        op_kwargs={"TransformId": transform_id, "OutputS3Path": output_s3_path},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    group_name: str = None,
    group_arn: str = None,
    entity_selector_expression: str = None,
    period: int = None,
    forecast_statistics: bool = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get an aggregation of service statistics defined by a specific time range.

    Args:
        start_time(str): The start of the time frame for which to aggregate statistics.
        end_time(str): The end of the time frame for which to aggregate statistics.
        group_name(str, optional): The case-sensitive name of the group for which to pull statistics from. Defaults to None.
        group_arn(str, optional): The Amazon Resource Name (ARN) of the group for which to pull statistics from. Defaults to None.
        entity_selector_expression(str, optional): A filter expression defining entities that will be aggregated for statistics. Supports ID, service, and edge functions. If no selector expression is specified, edge statistics are returned. . Defaults to None.
        period(int, optional): Aggregation period in seconds. Defaults to None.
        forecast_statistics(bool, optional): The forecasted high and low fault count values. Forecast enabled requests require the EntitySelectorExpression ID be provided. Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.time_series_service_statistic.get_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.time_series_service_statistic.get_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_time_series_service_statistics",
        op_kwargs={
            "StartTime": start_time,
            "EndTime": end_time,
            "GroupName": group_name,
            "GroupARN": group_arn,
            "EntitySelectorExpression": entity_selector_expression,
            "Period": period,
            "ForecastStatistics": forecast_statistics,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, access_token: str, mfa_options: List) -> Dict:
    r"""
    **Autogenerated function**

     This action is no longer supported. You can use it to configure only SMS MFA. You can't use it to configure TOTP software token MFA. To configure either type of MFA, use SetUserMFAPreference instead.

    Args:
        access_token(str): The access token for the set user settings request.
        mfa_options(List): You can use this parameter only to set an SMS configuration that uses SMS for delivery.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.setting.set(
                ctx, access_token=value, mfa_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.setting.set access_token=value, mfa_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="set_user_settings",
        op_kwargs={"AccessToken": access_token, "MFAOptions": mfa_options},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    aws_account_id: str,
    template_id: str,
    alias_name: str,
    template_version_number: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a template alias for a template.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template that you creating an alias for.
        template_id(str): An ID for the template.
        alias_name(str): The name that you want to give to the template alias that you're creating. Don't start the alias name with the $ character. Alias names that start with $ are reserved by Amazon QuickSight. .
        template_version_number(int): The version number of the template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.alias.create(
                ctx,
                aws_account_id=value,
                template_id=value,
                alias_name=value,
                template_version_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.alias.create aws_account_id=value, template_id=value, alias_name=value, template_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_template_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "AliasName": alias_name,
            "TemplateVersionNumber": template_version_number,
        },
    )


async def delete(
    hub, ctx, aws_account_id: str, template_id: str, alias_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the item that the specified template alias points to. If you provide a specific alias, you delete the version of the template that the alias points to.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the item to delete.
        template_id(str): The ID for the template that the specified alias is for.
        alias_name(str): The name for the template alias. To delete a specific alias, you delete the version that the alias points to. You can specify the alias name, or specify the latest version of the template by providing the keyword $LATEST in the AliasName parameter. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.alias.delete(
                ctx, aws_account_id=value, template_id=value, alias_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.alias.delete aws_account_id=value, template_id=value, alias_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_template_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "AliasName": alias_name,
        },
    )


async def describe(
    hub, ctx, aws_account_id: str, template_id: str, alias_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the template alias for a template.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template alias that you're describing.
        template_id(str): The ID for the template.
        alias_name(str): The name of the template alias that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the template by providing the keyword $LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't apply to templates.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.alias.describe(
                ctx, aws_account_id=value, template_id=value, alias_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.alias.describe aws_account_id=value, template_id=value, alias_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_template_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "AliasName": alias_name,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    template_id: str,
    alias_name: str,
    template_version_number: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the template alias of a template.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template alias that you're updating.
        template_id(str): The ID for the template.
        alias_name(str): The alias of the template that you want to update. If you name a specific alias, you update the version that the alias points to. You can specify the latest version of the template by providing the keyword $LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't apply to templates.
        template_version_number(int): The version number of the template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.alias.update(
                ctx,
                aws_account_id=value,
                template_id=value,
                alias_name=value,
                template_version_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.alias.update aws_account_id=value, template_id=value, alias_name=value, template_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_template_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "AliasName": alias_name,
            "TemplateVersionNumber": template_version_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def finalize(hub, ctx, device_id: str, tags: Dict = None) -> Dict:
    r"""
        **Autogenerated function**

        Given a device ID, finalizes the claim request for the associated device.
        Claiming a device consists of initiating a claim, then publishing a device event,
         and finalizing the claim. For a device of type button, a device event can
         be published by simply clicking the device.


        Args:
            device_id(str): The unique identifier of the device.
            tags(Dict, optional): A collection of key/value pairs defining the resource tags. For example, {
     "tags": {"key1": "value1", "key2": "value2"} }. For more information, see AWS
     Tagging Strategies.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.iot1click_device.device.claim.finalize(ctx, device_id=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.iot1click_device.device.claim.finalize device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="finalize_device_claim",
        op_kwargs={"DeviceId": device_id, "Tags": tags},
    )


async def initiate(hub, ctx, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Given a device ID, initiates a claim request for the associated device.
    Claiming a device consists of initiating a claim, then publishing a device event,
     and finalizing the claim. For a device of type button, a device event can
     be published by simply clicking the device.


    Args:
        device_id(str): The unique identifier of the device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.claim.initiate(ctx, device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.claim.initiate device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="initiate_device_claim",
        op_kwargs={"DeviceId": device_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def change(hub, ctx, life_cycle: Dict, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Allows the user to set the SourceServer.LifeCycle.state property for specific Source Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER. This command only works if the Source Server is already launchable (dataReplicationInfo.lagDuration is not null.)

    Args:
        life_cycle(Dict): The request to change the source server migration lifecycle state.
        source_server_id(str): The request to change the source server migration lifecycle state by source server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.server_life_cycle_state.change(
                ctx, life_cycle=value, source_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.server_life_cycle_state.change life_cycle=value, source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="change_server_life_cycle_state",
        op_kwargs={"lifeCycle": life_cycle, "sourceServerID": source_server_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    pool_ids: List = None,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified IPv4 address pools.

    Args:
        pool_ids(List, optional): The IDs of the address pools. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        filters(List, optional): One or more filters.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.public_ipv4_pool.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.public_ipv4_pool.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_public_ipv4_pools",
        op_kwargs={
            "PoolIds": pool_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites one or more tags for the specified directory. Each directory can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique to each resource.

    Args:
        resource_id(str): Identifier (ID) for the directory to which to add the tag.
        tags(List): The tags to be assigned to the directory.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.tags.to_resource.add(ctx, resource_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.tags.to_resource.add resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceId": resource_id, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "replication_set"


async def create(hub, ctx, regions: Dict, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    A replication set replicates and encrypts your data to the provided Regions with the provided KMS key.

    Args:
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        regions(Dict): The Regions that Incident Manager replicates your data to. You can have up to three Regions in your replication set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.replication_set_.create(ctx, regions=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.replication_set.create regions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="create_replication_set",
        op_kwargs={"clientToken": client_token, "regions": regions},
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all Regions in your replication set. Deleting the replication set deletes all Incident Manager data.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the replication set you're deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.replication_set_.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.replication_set.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="delete_replication_set",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve your Incident Manager replication set.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the replication set you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.replication_set_.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.replication_set.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="get_replication_set",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists details about the replication set configured in your account.

    Args:
        max_results(int, optional): The maximum number of results per page. . Defaults to None.
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.replication_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.replication_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="list_replication_sets",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(hub, ctx, actions: List, arn: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Add or delete Regions from your replication set.

    Args:
        actions(List): An action to add or delete a Region.
        arn(str): The Amazon Resource Name (ARN) of the replication set you're updating.
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.replication_set_.update(
                ctx, actions=value, arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.replication_set.update actions=value, arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="update_replication_set",
        op_kwargs={"actions": actions, "arn": arn, "clientToken": client_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    deployment_duration_in_minutes: int,
    growth_factor: float,
    replicate_to: str,
    description: str = None,
    final_bake_time_in_minutes: int = None,
    growth_type: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes: the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.

    Args:
        name(str): A name for the deployment strategy.
        description(str, optional): A description of the deployment strategy. Defaults to None.
        deployment_duration_in_minutes(int): Total amount of time for a deployment to last.
        final_bake_time_in_minutes(int, optional): The amount of time AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic roll back. Defaults to None.
        growth_factor(float): The percentage of targets to receive a deployed configuration during each interval.
        growth_type(str, optional): The algorithm used to define how percentage grows over time. AWS AppConfig supports the following growth types:  Linear: For this type, AppConfig processes the deployment by dividing the total number of targets by the value specified for Step percentage. For example, a linear deployment that uses a Step percentage of 10 deploys the configuration to 10 percent of the hosts. After those deployments are complete, the system deploys the configuration to the next 10 percent. This continues until 100% of the targets have successfully received the configuration.  Exponential: For this type, AppConfig processes the deployment exponentially using the following formula: G*(2^N). In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:  2*(2^0)   2*(2^1)   2*(2^2)  Expressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets. Defaults to None.
        replicate_to(str): Save the deployment strategy to a Systems Manager (SSM) document.
        tags(Dict, optional): Metadata to assign to the deployment strategy. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.strategy.create(
                ctx,
                name=value,
                deployment_duration_in_minutes=value,
                growth_factor=value,
                replicate_to=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.strategy.create name=value, deployment_duration_in_minutes=value, growth_factor=value, replicate_to=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="create_deployment_strategy",
        op_kwargs={
            "Name": name,
            "Description": description,
            "DeploymentDurationInMinutes": deployment_duration_in_minutes,
            "FinalBakeTimeInMinutes": final_bake_time_in_minutes,
            "GrowthFactor": growth_factor,
            "GrowthType": growth_type,
            "ReplicateTo": replicate_to,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, deployment_strategy_id: str) -> None:
    r"""
    **Autogenerated function**

    Delete a deployment strategy. Deleting a deployment strategy does not delete a configuration from a host.

    Args:
        deployment_strategy_id(str): The ID of the deployment strategy you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.strategy.delete(
                ctx, deployment_strategy_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.strategy.delete deployment_strategy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="delete_deployment_strategy",
        op_kwargs={"DeploymentStrategyId": deployment_strategy_id},
    )


async def get(hub, ctx, deployment_strategy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about a deployment strategy. A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes: the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.

    Args:
        deployment_strategy_id(str): The ID of the deployment strategy to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.strategy.get(
                ctx, deployment_strategy_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.strategy.get deployment_strategy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_deployment_strategy",
        op_kwargs={"DeploymentStrategyId": deployment_strategy_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List deployment strategies.

    Args:
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.strategy.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.strategy.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="list_deployment_strategies",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    deployment_strategy_id: str,
    description: str = None,
    deployment_duration_in_minutes: int = None,
    final_bake_time_in_minutes: int = None,
    growth_factor: float = None,
    growth_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a deployment strategy.

    Args:
        deployment_strategy_id(str): The deployment strategy ID.
        description(str, optional): A description of the deployment strategy. Defaults to None.
        deployment_duration_in_minutes(int, optional): Total amount of time for a deployment to last. Defaults to None.
        final_bake_time_in_minutes(int, optional): The amount of time AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic roll back. Defaults to None.
        growth_factor(float, optional): The percentage of targets to receive a deployed configuration during each interval. Defaults to None.
        growth_type(str, optional): The algorithm used to define how percentage grows over time. AWS AppConfig supports the following growth types:  Linear: For this type, AppConfig processes the deployment by increments of the growth factor evenly distributed over the deployment time. For example, a linear deployment that uses a growth factor of 20 initially makes the configuration available to 20 percent of the targets. After 1/5th of the deployment time has passed, the system updates the percentage to 40 percent. This continues until 100% of the targets are set to receive the deployed configuration.  Exponential: For this type, AppConfig processes the deployment exponentially using the following formula: G*(2^N). In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:  2*(2^0)   2*(2^1)   2*(2^2)  Expressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.strategy.update(
                ctx, deployment_strategy_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.strategy.update deployment_strategy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="update_deployment_strategy",
        op_kwargs={
            "DeploymentStrategyId": deployment_strategy_id,
            "Description": description,
            "DeploymentDurationInMinutes": deployment_duration_in_minutes,
            "FinalBakeTimeInMinutes": final_bake_time_in_minutes,
            "GrowthFactor": growth_factor,
            "GrowthType": growth_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    data_source: str,
    index_name: str,
    pricing_plan: str,
    data_source_configuration: Dict = None,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a place index resource in your AWS account, which supports functions with geospatial data sourced from your chosen data provider.

    Args:
        data_source(str): Specifies the data provider of geospatial data.  This field is case-sensitive. Enter the valid values as shown. For example, entering HERE returns an error.  Valid values include:    Esri – For additional information about Esri's coverage in your region of interest, see Esri details on geocoding coverage.    Here – For additional information about HERE Technologies's coverage in your region of interest, see HERE details on goecoding coverage.  Place index resources using HERE Technologies as a data provider can't store results for locations in Japan. For more information, see the AWS Service Terms for Amazon Location Service.    For additional information , see Data providers on the Amazon Location Service Developer Guide.
        data_source_configuration(Dict, optional): Specifies the data storage option requesting Places. Defaults to None.
        description(str, optional): The optional description for the place index resource. Defaults to None.
        index_name(str): The name of the place index resource.  Requirements:   Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).   Must be a unique place index resource name.   No spaces allowed. For example, ExamplePlaceIndex.  .
        pricing_plan(str): Specifies the pricing plan for your place index resource. For additional details and restrictions on each pricing plan option, see the Amazon Location Service pricing page.
        tags(Dict, optional): Applies one or more tags to the place index resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them. Format: "key" : "value"  Restrictions:   Maximum 50 tags per resource   Each resource tag must be unique with a maximum of one value.   Maximum key length: 128 Unicode characters in UTF-8   Maximum value length: 256 Unicode characters in UTF-8   Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.init.create(
                ctx, data_source=value, index_name=value, pricing_plan=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.init.create data_source=value, index_name=value, pricing_plan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="create_place_index",
        op_kwargs={
            "DataSource": data_source,
            "DataSourceConfiguration": data_source_configuration,
            "Description": description,
            "IndexName": index_name,
            "PricingPlan": pricing_plan,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, index_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a place index resource from your AWS account.  This operation deletes the resource permanently.

    Args:
        index_name(str): The name of the place index resource to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.init.delete(ctx, index_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.init.delete index_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="delete_place_index",
        op_kwargs={"IndexName": index_name},
    )


async def describe(hub, ctx, index_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the place index resource details.

    Args:
        index_name(str): The name of the place index resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.init.describe(ctx, index_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.init.describe index_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="describe_place_index",
        op_kwargs={"IndexName": index_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists place index resources in your AWS account.

    Args:
        max_results(int, optional): An optional limit for the maximum number of results returned in a single call. Default value: 100 . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page. Default value: null . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_place_indexes",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    index_name: str,
    data_source_configuration: Dict = None,
    description: str = None,
    pricing_plan: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified properties of a given place index resource.

    Args:
        data_source_configuration(Dict, optional): Updates the data storage option for the place index resource. Defaults to None.
        description(str, optional): Updates the description for the place index resource. Defaults to None.
        index_name(str): The name of the place index resource to update.
        pricing_plan(str, optional): Updates the pricing plan for the place index resource. For more information about each pricing plan option restrictions, see Amazon Location Service pricing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.init.update(ctx, index_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.init.update index_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="update_place_index",
        op_kwargs={
            "DataSourceConfiguration": data_source_configuration,
            "Description": description,
            "IndexName": index_name,
            "PricingPlan": pricing_plan,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    backup_vault_name: str,
    next_token: str = None,
    max_results: int = None,
    by_resource_arn: str = None,
    by_resource_type: str = None,
    by_backup_plan_id: str = None,
    by_created_before: str = None,
    by_created_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about the recovery points stored in a backup vault.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.
        by_resource_arn(str, optional): Returns only recovery points that match the specified resource Amazon Resource Name (ARN). Defaults to None.
        by_resource_type(str, optional): Returns only recovery points that match the specified resource type. Defaults to None.
        by_backup_plan_id(str, optional): Returns only recovery points that match the specified backup plan ID. Defaults to None.
        by_created_before(str, optional): Returns only recovery points that were created before the specified timestamp. Defaults to None.
        by_created_after(str, optional): Returns only recovery points that were created after the specified timestamp. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.by.backup_vault.list(
                ctx, backup_vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.by.backup_vault.list backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_recovery_points_by_backup_vault",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ByResourceArn": by_resource_arn,
            "ByResourceType": by_resource_type,
            "ByBackupPlanId": by_backup_plan_id,
            "ByCreatedBefore": by_created_before,
            "ByCreatedAfter": by_created_after,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    distribution_name: str,
    metric_name: str,
    start_time: str,
    end_time: str,
    period: int,
    unit: str,
    statistics: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data points of a specific metric for an Amazon Lightsail content delivery network (CDN) distribution. Metrics report the utilization of your resources, and the error counts generated by them. Monitor and collect metric data regularly to maintain the reliability, availability, and performance of your resources.

    Args:
        distribution_name(str): The name of the distribution for which to get metric data. Use the GetDistributions action to get a list of distribution names that you can specify.
        metric_name(str): The metric for which you want to return information. Valid distribution metric names are listed below, along with the most useful statistics to include in your request, and the published unit value.     Requests  - The total number of viewer requests received by your Lightsail distribution, for all HTTP methods, and for both HTTP and HTTPS requests.  Statistics: The most useful statistic is Sum.  Unit: The published unit is None.     BytesDownloaded  - The number of bytes downloaded by viewers for GET, HEAD, and OPTIONS requests.  Statistics: The most useful statistic is Sum.  Unit: The published unit is None.     BytesUploaded   - The number of bytes uploaded to your origin by your Lightsail distribution, using POST and PUT requests.  Statistics: The most useful statistic is Sum.  Unit: The published unit is None.     TotalErrorRate  - The percentage of all viewer requests for which the response's HTTP status code was 4xx or 5xx.  Statistics: The most useful statistic is Average.  Unit: The published unit is Percent.     4xxErrorRate  - The percentage of all viewer requests for which the response's HTTP status cod was 4xx. In these cases, the client or client viewer may have made an error. For example, a status code of 404 (Not Found) means that the client requested an object that could not be found.  Statistics: The most useful statistic is Average.  Unit: The published unit is Percent.     5xxErrorRate  - The percentage of all viewer requests for which the response's HTTP status code was 5xx. In these cases, the origin server did not satisfy the requests. For example, a status code of 503 (Service Unavailable) means that the origin server is currently unavailable.  Statistics: The most useful statistic is Average.  Unit: The published unit is Percent.  .
        start_time(str): The start of the time interval for which to get metric data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use a start time of October 1, 2018, at 8 PM UTC, specify 1538424000 as the start time.   You can convert a human-friendly time to Unix time format using a converter like Epoch converter.
        end_time(str): The end of the time interval for which to get metric data. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use an end time of October 1, 2018, at 9 PM UTC, specify 1538427600 as the end time.   You can convert a human-friendly time to Unix time format using a converter like Epoch converter.
        period(int): The granularity, in seconds, for the metric data points that will be returned.
        unit(str): The unit for the metric data request. Valid units depend on the metric data being requested. For the valid units with each available metric, see the metricName parameter.
        statistics(List): The statistic for the metric. The following statistics are available:    Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.    Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.    Sum - All values submitted for the matching metric added together. You can use this statistic to determine the total volume of a metric.    Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.    SampleCount - The count, or number, of data points used for the statistical calculation.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.metric_data.get(
                ctx,
                distribution_name=value,
                metric_name=value,
                start_time=value,
                end_time=value,
                period=value,
                unit=value,
                statistics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.metric_data.get distribution_name=value, metric_name=value, start_time=value, end_time=value, period=value, unit=value, statistics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_distribution_metric_data",
        op_kwargs={
            "distributionName": distribution_name,
            "metricName": metric_name,
            "startTime": start_time,
            "endTime": end_time,
            "period": period,
            "unit": unit,
            "statistics": statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def reload(
    hub,
    ctx,
    replication_task_arn: str,
    tables_to_reload: List,
    reload_option: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Reloads the target database table with the source data.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the replication task. .
        tables_to_reload(List): The name and schema of the table to be reloaded. .
        reload_option(str, optional): Options for reload. Specify data-reload to reload the data and re-validate it if validation is enabled. Specify validate-only to re-validate the table. This option applies only when validation is enabled for the task.  Valid values: data-reload, validate-only Default value is data-reload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.table.init.reload(
                ctx, replication_task_arn=value, tables_to_reload=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.table.init.reload replication_task_arn=value, tables_to_reload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="reload_tables",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "TablesToReload": tables_to_reload,
            "ReloadOption": reload_option,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, parameter_group_family: str, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of parameter settings for the specified parameter group family.  For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        parameter_group_family(str): The name of the cluster parameter group family.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDefaultClusterParameters request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.default_cluster_parameter.describe_all(
                ctx, parameter_group_family=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.default_cluster_parameter.describe_all parameter_group_family=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_default_cluster_parameters",
        op_kwargs={
            "ParameterGroupFamily": parameter_group_family,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, api_id: str, description: str = None, stage_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Deployment for an API.

    Args:
        api_id(str): The API identifier.
        description(str, optional): The description for the deployment resource. Defaults to None.
        stage_name(str, optional): The name of the Stage resource for the Deployment resource to create. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.deployment.create(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.deployment.create api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_deployment",
        op_kwargs={
            "ApiId": api_id,
            "Description": description,
            "StageName": stage_name,
        },
    )


async def delete(hub, ctx, api_id: str, deployment_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Deployment.

    Args:
        api_id(str): The API identifier.
        deployment_id(str): The deployment ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.deployment.delete(
                ctx, api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.deployment.delete api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_deployment",
        op_kwargs={"ApiId": api_id, "DeploymentId": deployment_id},
    )


async def get(hub, ctx, api_id: str, deployment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a Deployment.

    Args:
        api_id(str): The API identifier.
        deployment_id(str): The deployment ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.deployment.get(
                ctx, api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.deployment.get api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_deployment",
        op_kwargs={"ApiId": api_id, "DeploymentId": deployment_id},
    )


async def get_all(
    hub, ctx, api_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Deployments for an API.

    Args:
        api_id(str): The API identifier.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.deployment.get_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.deployment.get_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_deployments",
        op_kwargs={"ApiId": api_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, api_id: str, deployment_id: str, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Deployment.

    Args:
        api_id(str): The API identifier.
        deployment_id(str): The deployment ID.
        description(str, optional): The description for the deployment resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.deployment.update(
                ctx, api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.deployment.update api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_deployment",
        op_kwargs={
            "ApiId": api_id,
            "DeploymentId": deployment_id,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, domain_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the complete history of the last 10 upgrades that were performed on the domain.

    Args:
        domain_name(str): The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        max_results(int, optional):  Set this value to limit the number of results returned. . Defaults to None.
        next_token(str, optional):  Paginated APIs accepts NextToken input to returns next page results and provides a NextToken output in the response which can be used by the client to retrieve more results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.upgrade.history.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.upgrade.history.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="get_upgrade_history",
        op_kwargs={
            "DomainName": domain_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    description: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Traffic Mirror filter. A Traffic Mirror filter is a set of rules that defines the traffic to mirror. By default, no traffic is mirrored. To mirror traffic, use CreateTrafficMirrorFilterRule to add Traffic Mirror rules to the filter. The rules you add define what traffic gets mirrored. You can also use ModifyTrafficMirrorFilterNetworkServices to mirror supported network services.

    Args:
        description(str, optional): The description of the Traffic Mirror filter. Defaults to None.
        tag_specifications(List, optional): The tags to assign to a Traffic Mirror filter. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.filter_.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.filter_.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_traffic_mirror_filter",
        op_kwargs={
            "Description": description,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, traffic_mirror_filter_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Traffic Mirror filter. You cannot delete a Traffic Mirror filter that is in use by a Traffic Mirror session.

    Args:
        traffic_mirror_filter_id(str): The ID of the Traffic Mirror filter.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.filter_.init.delete(
                ctx, traffic_mirror_filter_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.filter_.init.delete traffic_mirror_filter_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_traffic_mirror_filter",
        op_kwargs={
            "TrafficMirrorFilterId": traffic_mirror_filter_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    traffic_mirror_filter_ids: List = None,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more Traffic Mirror filters.

    Args:
        traffic_mirror_filter_ids(List, optional): The ID of the Traffic Mirror filter. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    description: The Traffic Mirror filter description.    traffic-mirror-filter-id: The ID of the Traffic Mirror filter.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.filter_.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.filter_.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_traffic_mirror_filters",
        op_kwargs={
            "TrafficMirrorFilterIds": traffic_mirror_filter_ids,
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, file_system_association_arn_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets the file system association information. This operation is only supported for FSx File Gateways.

    Args:
        file_system_association_arn_list(List): An array containing the Amazon Resource Name (ARN) of each file system association to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.system.association.describe_all(
                ctx, file_system_association_arn_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.system.association.describe_all file_system_association_arn_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_file_system_associations",
        op_kwargs={"FileSystemAssociationARNList": file_system_association_arn_list},
    )


async def list_all(
    hub, ctx, gateway_arn: str = None, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of FileSystemAssociationSummary objects. Each object contains a summary of a file system association. This operation is only supported for FSx File Gateways.

    Args:
        gateway_arn(str, optional): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region. Defaults to None.
        limit(int, optional): The maximum number of file system associations to return in the response. If present, Limit must be an integer with a value greater than zero. Optional. Defaults to None.
        marker(str, optional): Opaque pagination token returned from a previous ListFileSystemAssociations operation. If present, Marker specifies where to continue the list from after a previous call to ListFileSystemAssociations. Optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.system.association.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.system.association.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_file_system_associations",
        op_kwargs={"GatewayARN": gateway_arn, "Limit": limit, "Marker": marker},
    )


async def update(
    hub,
    ctx,
    file_system_association_arn: str,
    user_name: str = None,
    password: str = None,
    audit_destination_arn: str = None,
    cache_attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a file system association. This operation is only supported in the FSx File Gateways.

    Args:
        file_system_association_arn(str): The Amazon Resource Name (ARN) of the file system association that you want to update.
        user_name(str, optional): The user name of the user credential that has permission to access the root share D$ of the Amazon FSx file system. The user account must belong to the Amazon FSx delegated admin user group. Defaults to None.
        password(str, optional): The password of the user credential. Defaults to None.
        audit_destination_arn(str, optional): The Amazon Resource Name (ARN) of the storage used for the audit logs. Defaults to None.
        cache_attributes(Dict, optional): The refresh cache information for the file share or FSx file systems. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.system.association.update(
                ctx, file_system_association_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.system.association.update file_system_association_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_file_system_association",
        op_kwargs={
            "FileSystemAssociationARN": file_system_association_arn,
            "UserName": user_name,
            "Password": password,
            "AuditDestinationARN": audit_destination_arn,
            "CacheAttributes": cache_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    offering_ids: List = None,
    payment_options: List = None,
    product_type: str = None,
    plan_types: List = None,
    durations: List = None,
    currencies: List = None,
    descriptions: List = None,
    service_codes: List = None,
    usage_types: List = None,
    operations: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Savings Plans offerings.

    Args:
        offering_ids(List, optional): The IDs of the offerings. Defaults to None.
        payment_options(List, optional): The payment options. Defaults to None.
        product_type(str, optional): The product type. Defaults to None.
        plan_types(List, optional): The plan type. Defaults to None.
        durations(List, optional): The durations, in seconds. Defaults to None.
        currencies(List, optional): The currencies. Defaults to None.
        descriptions(List, optional): The descriptions. Defaults to None.
        service_codes(List, optional): The services. Defaults to None.
        usage_types(List, optional): The usage details of the line item in the billing report. Defaults to None.
        operations(List, optional): The specific AWS operation for the line item in the billing report. Defaults to None.
        filters(List, optional): The filters. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve additional results, make another call with the returned token value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.savingsplan.saving_plan.offering.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.savingsplan.saving_plan.offering.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="savingsplans",
        operation="describe_savings_plans_offerings",
        op_kwargs={
            "offeringIds": offering_ids,
            "paymentOptions": payment_options,
            "productType": product_type,
            "planTypes": plan_types,
            "durations": durations,
            "currencies": currencies,
            "descriptions": descriptions,
            "serviceCodes": service_codes,
            "usageTypes": usage_types,
            "operations": operations,
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, calendar_names: List, at_time: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the state of a Amazon Web Services Systems Manager change calendar at the current time or a specified time. If you specify a time, GetCalendarState returns the state of the calendar at that specific time, and returns the next time that the change calendar state will transition. If you don't specify a time, GetCalendarState uses the current time. Change Calendar entries have two possible states: OPEN or CLOSED. If you specify more than one calendar in a request, the command returns the status of OPEN only if all calendars in the request are open. If one or more calendars in the request are closed, the status returned is CLOSED. For more information about Change Calendar, a capability of Amazon Web Services Systems Manager, see Amazon Web Services Systems Manager Change Calendar in the Amazon Web Services Systems Manager User Guide.

    Args:
        calendar_names(List): The names or Amazon Resource Names (ARNs) of the Systems Manager documents (SSM documents) that represent the calendar entries for which you want to get the state.
        at_time(str, optional): (Optional) The specific time for which you want to get calendar state information, in ISO 8601 format. If you don't specify a value or AtTime, the current time is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.calendar_state.get(ctx, calendar_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.calendar_state.get calendar_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_calendar_state",
        op_kwargs={"CalendarNames": calendar_names, "AtTime": at_time},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub, ctx, identity: str, notification_type: str, sns_topic: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sets an Amazon Simple Notification Service (Amazon SNS) topic to use when delivering notifications. When you use this operation, you specify a verified identity, such as an email address or domain. When you send an email that uses the chosen identity in the Source field, Amazon SES sends notifications to the topic you specified. You can send bounce, complaint, or delivery notifications (or any combination of the three) to the Amazon SNS topic that you specify. You can execute this operation no more than once per second. For more information about feedback notification, see the Amazon SES Developer Guide.

    Args:
        identity(str): The identity (email address or domain) that you want to set the Amazon SNS topic for.  You can only specify a verified identity for this parameter.  You can specify an identity by using its name or by using its Amazon Resource Name (ARN). The following examples are all valid identities: sender@example.com, example.com, arn:aws:ses:us-east-1:123456789012:identity/example.com.
        notification_type(str): The type of notifications that will be published to the specified Amazon SNS topic.
        sns_topic(str, optional): The Amazon Resource Name (ARN) of the Amazon SNS topic. If the parameter is omitted from the request or a null value is passed, SnsTopic is cleared and publishing is disabled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.notification.topic.set(
                ctx, identity=value, notification_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.notification.topic.set identity=value, notification_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="set_identity_notification_topic",
        op_kwargs={
            "Identity": identity,
            "NotificationType": notification_type,
            "SnsTopic": sns_topic,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def abort(hub, ctx, account_id: str, vault_name: str) -> None:
    r"""
    **Autogenerated function**

    This operation aborts the vault locking process if the vault lock is not in the Locked state. If the vault lock is in the Locked state when this operation is requested, the operation returns an AccessDeniedException error. Aborting the vault locking process removes the vault lock policy from the specified vault.  A vault lock is put into the InProgress state by calling InitiateVaultLock. A vault lock is put into the Locked state by calling CompleteVaultLock. You can get the state of a vault lock by calling GetVaultLock. For more information about the vault locking process, see Amazon Glacier Vault Lock. For more information about vault lock policies, see Amazon Glacier Access Control with Vault Lock Policies.  This operation is idempotent. You can successfully invoke this operation multiple times, if the vault lock is in the InProgress state or if there is no policy associated with the vault.

    Args:
        account_id(str): The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.lock.abort(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.lock.abort account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="abort_vault_lock",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def complete(hub, ctx, account_id: str, vault_name: str, lock_id: str) -> None:
    r"""
    **Autogenerated function**

    This operation completes the vault locking process by transitioning the vault lock from the InProgress state to the Locked state, which causes the vault lock policy to become unchangeable. A vault lock is put into the InProgress state by calling InitiateVaultLock. You can obtain the state of the vault lock by calling GetVaultLock. For more information about the vault locking process, Amazon Glacier Vault Lock.  This operation is idempotent. This request is always successful if the vault lock is in the Locked state and the provided lock ID matches the lock ID originally used to lock the vault. If an invalid lock ID is passed in the request when the vault lock is in the Locked state, the operation returns an AccessDeniedException error. If an invalid lock ID is passed in the request when the vault lock is in the InProgress state, the operation throws an InvalidParameter error.

    Args:
        account_id(str): The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        lock_id(str): The lockId value is the lock ID obtained from a InitiateVaultLock request.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.lock.complete(
                ctx, account_id=value, vault_name=value, lock_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.lock.complete account_id=value, vault_name=value, lock_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="complete_vault_lock",
        op_kwargs={"accountId": account_id, "vaultName": vault_name, "lockId": lock_id},
    )


async def get(hub, ctx, account_id: str, vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation retrieves the following attributes from the lock-policy subresource set on the specified vault:    The vault lock policy set on the vault.   The state of the vault lock, which is either InProgess or Locked.   When the lock ID expires. The lock ID is used to complete the vault locking process.   When the vault lock was initiated and put into the InProgress state.   A vault lock is put into the InProgress state by calling InitiateVaultLock. A vault lock is put into the Locked state by calling CompleteVaultLock. You can abort the vault locking process by calling AbortVaultLock. For more information about the vault locking process, Amazon Glacier Vault Lock.  If there is no vault lock policy set on the vault, the operation returns a 404 Not found error. For more information about vault lock policies, Amazon Glacier Access Control with Vault Lock Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.lock.get(ctx, account_id=value, vault_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.lock.get account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="get_vault_lock",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def initiate(
    hub, ctx, account_id: str, vault_name: str, policy: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation initiates the vault locking process by doing the following:   Installing a vault lock policy on the specified vault.   Setting the lock state of vault lock to InProgress.   Returning a lock ID, which is used to complete the vault locking process.   You can set one vault lock policy for each vault and this policy can be up to 20 KB in size. For more information about vault lock policies, see Amazon Glacier Access Control with Vault Lock Policies.  You must complete the vault locking process within 24 hours after the vault lock enters the InProgress state. After the 24 hour window ends, the lock ID expires, the vault automatically exits the InProgress state, and the vault lock policy is removed from the vault. You call CompleteVaultLock to complete the vault locking process by setting the state of the vault lock to Locked.  After a vault lock is in the Locked state, you cannot initiate a new vault lock for the vault. You can abort the vault locking process by calling AbortVaultLock. You can get the state of the vault lock by calling GetVaultLock. For more information about the vault locking process, Amazon Glacier Vault Lock. If this operation is called when the vault lock is in the InProgress state, the operation returns an AccessDeniedException error. When the vault lock is in the InProgress state you must call AbortVaultLock before you can initiate a new vault lock policy.

    Args:
        account_id(str): The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        policy(Dict, optional): The vault lock policy as a JSON string, which uses "\" as an escape character. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.lock.initiate(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.lock.initiate account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="initiate_vault_lock",
        op_kwargs={"accountId": account_id, "vaultName": vault_name, "policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified Region. For more information, see Key management in the IoT SiteWise User Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.default_encryption_configuration.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.default_encryption_configuration.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_default_encryption_configuration",
        op_kwargs={},
    )


async def put(hub, ctx, encryption_type: str, kms_key_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Sets the default encryption configuration for the Amazon Web Services account. For more information, see Key management in the IoT SiteWise User Guide.

    Args:
        encryption_type(str): The type of encryption used for the encryption configuration.
        kms_key_id(str, optional): The Key ID of the customer managed customer master key (CMK) used for KMS encryption. This is required if you use KMS_BASED_ENCRYPTION. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.default_encryption_configuration.put(
                ctx, encryption_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.default_encryption_configuration.put encryption_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="put_default_encryption_configuration",
        op_kwargs={"encryptionType": encryption_type, "kmsKeyId": kms_key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(hub, ctx, account_id: str, vault_name: str, tags: Dict = None) -> None:
    r"""
    **Autogenerated function**

    This operation adds the specified tags to a vault. Each tag is composed of a key and a value. Each vault can have up to 10 tags. If your request would cause the tag limit for the vault to be exceeded, the operation throws the LimitExceededException error. If a tag already exists on the vault under a specified key, the existing key value will be overwritten. For more information about tags, see Tagging Amazon S3 Glacier Resources.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        tags(Dict, optional): The tags to add to the vault. Each tag is composed of a key and a value. The value can be an empty string. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.tags.to_vault.add(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.tags.to_vault.add account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="add_tags_to_vault",
        op_kwargs={"accountId": account_id, "vaultName": vault_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    page_size: str = None,
    prefix: str = None,
    template_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the message templates that are associated with your Amazon Pinpoint account.

    Args:
        next_token(str, optional): The  string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        prefix(str, optional): The substring to match in the names of the message templates to include in the results. If you specify this value, Amazon Pinpoint returns only those templates whose names begin with the value that you specify. Defaults to None.
        template_type(str, optional): The type of message template to include in the results. Valid values are: EMAIL, PUSH, SMS, and VOICE. To include all types of templates in the results, don't include this parameter in your request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="list_templates",
        op_kwargs={
            "NextToken": next_token,
            "PageSize": page_size,
            "Prefix": prefix,
            "TemplateType": template_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    stage_name: str,
    access_log_settings: Dict = None,
    auto_deploy: bool = None,
    client_certificate_id: str = None,
    default_route_settings: Dict = None,
    deployment_id: str = None,
    description: str = None,
    route_settings: Dict = None,
    stage_variables: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Stage for an API.

    Args:
        access_log_settings(Dict, optional): Settings for logging access in this stage. Defaults to None.
        api_id(str): The API identifier.
        auto_deploy(bool, optional): Specifies whether updates to an API automatically trigger a new deployment. The default value is false. Defaults to None.
        client_certificate_id(str, optional): The identifier of a client certificate for a Stage. Supported only for WebSocket APIs. Defaults to None.
        default_route_settings(Dict, optional): The default route settings for the stage. Defaults to None.
        deployment_id(str, optional): The deployment identifier of the API stage. Defaults to None.
        description(str, optional): The description for the API stage. Defaults to None.
        route_settings(Dict, optional): Route settings for the stage, by routeKey. Defaults to None.
        stage_name(str): The name of the stage.
        stage_variables(Dict, optional): A map that defines the stage variables for a Stage. Variable names can have alphanumeric and underscore characters, and the values must match [A-Za-z0-9-._~:/?#&=,]+. Defaults to None.
        tags(Dict, optional): The collection of tags. Each tag element is associated with a given resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.stage.create(ctx, api_id=value, stage_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.stage.create api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_stage",
        op_kwargs={
            "AccessLogSettings": access_log_settings,
            "ApiId": api_id,
            "AutoDeploy": auto_deploy,
            "ClientCertificateId": client_certificate_id,
            "DefaultRouteSettings": default_route_settings,
            "DeploymentId": deployment_id,
            "Description": description,
            "RouteSettings": route_settings,
            "StageName": stage_name,
            "StageVariables": stage_variables,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, api_id: str, stage_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Stage.

    Args:
        api_id(str): The API identifier.
        stage_name(str): The stage name. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.stage.delete(ctx, api_id=value, stage_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.stage.delete api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_stage",
        op_kwargs={"ApiId": api_id, "StageName": stage_name},
    )


async def get(hub, ctx, api_id: str, stage_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a Stage.

    Args:
        api_id(str): The API identifier.
        stage_name(str): The stage name. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.stage.get(ctx, api_id=value, stage_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.stage.get api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_stage",
        op_kwargs={"ApiId": api_id, "StageName": stage_name},
    )


async def get_all(
    hub, ctx, api_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Stages for an API.

    Args:
        api_id(str): The API identifier.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.stage.get_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.stage.get_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_stages",
        op_kwargs={"ApiId": api_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    api_id: str,
    stage_name: str,
    access_log_settings: Dict = None,
    auto_deploy: bool = None,
    client_certificate_id: str = None,
    default_route_settings: Dict = None,
    deployment_id: str = None,
    description: str = None,
    route_settings: Dict = None,
    stage_variables: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Stage.

    Args:
        access_log_settings(Dict, optional): Settings for logging access in this stage. Defaults to None.
        api_id(str): The API identifier.
        auto_deploy(bool, optional): Specifies whether updates to an API automatically trigger a new deployment. The default value is false. Defaults to None.
        client_certificate_id(str, optional): The identifier of a client certificate for a Stage. Defaults to None.
        default_route_settings(Dict, optional): The default route settings for the stage. Defaults to None.
        deployment_id(str, optional): The deployment identifier for the API stage. Can't be updated if autoDeploy is enabled. Defaults to None.
        description(str, optional): The description for the API stage. Defaults to None.
        route_settings(Dict, optional): Route settings for the stage. Defaults to None.
        stage_name(str): The stage name. Stage names can contain only alphanumeric characters, hyphens, and underscores, or be $default. Maximum length is 128 characters.
        stage_variables(Dict, optional): A map that defines the stage variables for a Stage. Variable names can have alphanumeric and underscore characters, and the values must match [A-Za-z0-9-._~:/?#&=,]+. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.stage.update(ctx, api_id=value, stage_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.stage.update api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_stage",
        op_kwargs={
            "AccessLogSettings": access_log_settings,
            "ApiId": api_id,
            "AutoDeploy": auto_deploy,
            "ClientCertificateId": client_certificate_id,
            "DefaultRouteSettings": default_route_settings,
            "DeploymentId": deployment_id,
            "Description": description,
            "RouteSettings": route_settings,
            "StageName": stage_name,
            "StageVariables": stage_variables,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    state_machine_arn: str,
    name: str = None,
    input_: str = None,
    trace_header: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a Synchronous Express state machine execution.

    Args:
        state_machine_arn(str): The Amazon Resource Name (ARN) of the state machine to execute.
        name(str, optional): The name of the execution. Defaults to None.
        input_(str, optional): The string that contains the JSON input data for the execution, for example:  "input": "{\"first_name\" : \"test\"}"   If you don't include any JSON input data, you still must include the two braces, for example: "input": "{}"   Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding. Defaults to None.
        trace_header(str, optional): Passes the AWS X-Ray trace header. The trace header can also be passed in the request payload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.sync_execution.start(ctx, state_machine_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.sync_execution.start state_machine_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="start_sync_execution",
        op_kwargs={
            "stateMachineArn": state_machine_arn,
            "name": name,
            "input": input_,
            "traceHeader": trace_header,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def respond(hub, ctx, task_token: str, details: str = None) -> None:
    r"""
    **Autogenerated function**

    Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled. Additional details can be provided using the details argument. These details (if provided) appear in the ActivityTaskCanceled event added to the workflow history.  Only use this operation if the canceled flag of a RecordActivityTaskHeartbeat request returns true and if the activity can be safely undone or abandoned.  A task is considered open from the time that it is scheduled until it is closed. Therefore a task is reported as open while a worker is processing it. A task is closed after it has been specified in a call to RespondActivityTaskCompleted, RespondActivityTaskCanceled, RespondActivityTaskFailed, or the task has timed out.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        task_token(str): The taskToken of the ActivityTask.   taskToken is generated by the service and should be treated as an opaque value. If the task is passed to another process, its taskToken must also be passed. This enables it to provide its progress and respond with results. .
        details(str, optional):  Information about the cancellation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.activity.task.canceled.respond(ctx, task_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.activity.task.canceled.respond task_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="respond_activity_task_canceled",
        op_kwargs={"taskToken": task_token, "details": details},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, address: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an address for a Snow device to be shipped to. In most regions, addresses are validated at the time of creation. The address you provide must be located within the serviceable area of your region. If the address is invalid or unsupported, then an exception is thrown.

    Args:
        address(Dict): The address that you want the Snow device shipped to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.address.create(ctx, address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.address.create address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="create_address",
        op_kwargs={"Address": address},
    )


async def describe(hub, ctx, address_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Takes an AddressId and returns specific details about that address in the form of an Address object.

    Args:
        address_id(str): The automatically generated ID for a specific address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.address.describe(ctx, address_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.address.describe address_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="describe_address",
        op_kwargs={"AddressId": address_id},
    )


async def describe_all(
    hub, ctx, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a specified number of ADDRESS objects. Calling this API in one of the US regions will return addresses from the list of all addresses associated with this account in all US regions.

    Args:
        max_results(int, optional): The number of ADDRESS objects to return. Defaults to None.
        next_token(str, optional): HTTP requests are stateless. To identify what object comes "next" in the list of ADDRESS objects, you have the option of specifying a value for NextToken as the starting point for your list of returned addresses. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.address.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.address.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="describe_addresses",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, alarm_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an alarm. An alarm is used to monitor a single metric for one of your resources. When a metric condition is met, the alarm can notify you by email, SMS text message, and a banner displayed on the Amazon Lightsail console. For more information, see Alarms in Amazon Lightsail.

    Args:
        alarm_name(str): The name of the alarm to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.alarm.delete(ctx, alarm_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.alarm.delete alarm_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_alarm",
        op_kwargs={"alarmName": alarm_name},
    )


async def get_all(
    hub,
    ctx,
    alarm_name: str = None,
    page_token: str = None,
    monitored_resource_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the configured alarms. Specify an alarm name in your request to return information about a specific alarm, or specify a monitored resource name to return information about all alarms for a specific resource. An alarm is used to monitor a single metric for one of your resources. When a metric condition is met, the alarm can notify you by email, SMS text message, and a banner displayed on the Amazon Lightsail console. For more information, see Alarms in Amazon Lightsail.

    Args:
        alarm_name(str, optional): The name of the alarm. Specify an alarm name to return information about a specific alarm. Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetAlarms request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.
        monitored_resource_name(str, optional): The name of the Lightsail resource being monitored by the alarm. Specify a monitored resource name to return information about all alarms for a specific resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.alarm.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.alarm.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_alarms",
        op_kwargs={
            "alarmName": alarm_name,
            "pageToken": page_token,
            "monitoredResourceName": monitored_resource_name,
        },
    )


async def put(
    hub,
    ctx,
    alarm_name: str,
    metric_name: str,
    monitored_resource_name: str,
    comparison_operator: str,
    threshold: float,
    evaluation_periods: int,
    datapoints_to_alarm: int = None,
    treat_missing_data: str = None,
    contact_protocols: List = None,
    notification_triggers: List = None,
    notification_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an alarm, and associates it with the specified metric. An alarm is used to monitor a single metric for one of your resources. When a metric condition is met, the alarm can notify you by email, SMS text message, and a banner displayed on the Amazon Lightsail console. For more information, see Alarms in Amazon Lightsail. When this action creates an alarm, the alarm state is immediately set to INSUFFICIENT_DATA. The alarm is then evaluated and its state is set appropriately. Any actions associated with the new state are then executed. When you update an existing alarm, its state is left unchanged, but the update completely overwrites the previous configuration of the alarm. The alarm is then evaluated with the updated configuration.

    Args:
        alarm_name(str): The name for the alarm. Specify the name of an existing alarm to update, and overwrite the previous configuration of the alarm.
        metric_name(str): The name of the metric to associate with the alarm. You can configure up to two alarms per metric. The following metrics are available for each resource type:    Instances: BurstCapacityPercentage, BurstCapacityTime, CPUUtilization, NetworkIn, NetworkOut, StatusCheckFailed, StatusCheckFailed_Instance, and StatusCheckFailed_System.    Load balancers: ClientTLSNegotiationErrorCount, HealthyHostCount, UnhealthyHostCount, HTTPCode_LB_4XX_Count, HTTPCode_LB_5XX_Count, HTTPCode_Instance_2XX_Count, HTTPCode_Instance_3XX_Count, HTTPCode_Instance_4XX_Count, HTTPCode_Instance_5XX_Count, InstanceResponseTime, RejectedConnectionCount, and RequestCount.    Relational databases: CPUUtilization, DatabaseConnections, DiskQueueDepth, FreeStorageSpace, NetworkReceiveThroughput, and NetworkTransmitThroughput.   For more information about these metrics, see Metrics available in Lightsail.
        monitored_resource_name(str): The name of the Lightsail resource that will be monitored. Instances, load balancers, and relational databases are the only Lightsail resources that can currently be monitored by alarms.
        comparison_operator(str): The arithmetic operation to use when comparing the specified statistic to the threshold. The specified statistic value is used as the first operand.
        threshold(float): The value against which the specified statistic is compared.
        evaluation_periods(int): The number of most recent periods over which data is compared to the specified threshold. If you are setting an "M out of N" alarm, this value (evaluationPeriods) is the N. If you are setting an alarm that requires that a number of consecutive data points be breaching to trigger the alarm, this value specifies the rolling period of time in which data points are evaluated. Each evaluation period is five minutes long. For example, specify an evaluation period of 24 to evaluate a metric over a rolling period of two hours. You can specify a minimum valuation period of 1 (5 minutes), and a maximum evaluation period of 288 (24 hours).
        datapoints_to_alarm(int, optional): The number of data points that must be not within the specified threshold to trigger the alarm. If you are setting an "M out of N" alarm, this value (datapointsToAlarm) is the M. Defaults to None.
        treat_missing_data(str, optional): Sets how this alarm will handle missing data points. An alarm can treat missing data in the following ways:    breaching - Assume the missing data is not within the threshold. Missing data counts towards the number of times the metric is not within the threshold.    notBreaching - Assume the missing data is within the threshold. Missing data does not count towards the number of times the metric is not within the threshold.    ignore - Ignore the missing data. Maintains the current alarm state.    missing - Missing data is treated as missing.   If treatMissingData is not specified, the default behavior of missing is used. Defaults to None.
        contact_protocols(List, optional): The contact protocols to use for the alarm, such as Email, SMS (text messaging), or both. A notification is sent via the specified contact protocol if notifications are enabled for the alarm, and when the alarm is triggered. A notification is not sent if a contact protocol is not specified, if the specified contact protocol is not configured in the AWS Region, or if notifications are not enabled for the alarm using the notificationEnabled paramater. Use the CreateContactMethod action to configure a contact protocol in an AWS Region. Defaults to None.
        notification_triggers(List, optional): The alarm states that trigger a notification. An alarm has the following possible states:    ALARM - The metric is outside of the defined threshold.    INSUFFICIENT_DATA - The alarm has just started, the metric is not available, or not enough data is available for the metric to determine the alarm state.    OK - The metric is within the defined threshold.   When you specify a notification trigger, the ALARM state must be specified. The INSUFFICIENT_DATA and OK states can be specified in addition to the ALARM state.   If you specify OK as an alarm trigger, a notification is sent when the alarm switches from an ALARM or INSUFFICIENT_DATA alarm state to an OK state. This can be thought of as an all clear alarm notification.   If you specify INSUFFICIENT_DATA as the alarm trigger, a notification is sent when the alarm switches from an OK or ALARM alarm state to an INSUFFICIENT_DATA state.   The notification trigger defaults to ALARM if you don't specify this parameter. Defaults to None.
        notification_enabled(bool, optional): Indicates whether the alarm is enabled. Notifications are enabled by default if you don't specify this parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.alarm.put(
                ctx,
                alarm_name=value,
                metric_name=value,
                monitored_resource_name=value,
                comparison_operator=value,
                threshold=value,
                evaluation_periods=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.alarm.put alarm_name=value, metric_name=value, monitored_resource_name=value, comparison_operator=value, threshold=value, evaluation_periods=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="put_alarm",
        op_kwargs={
            "alarmName": alarm_name,
            "metricName": metric_name,
            "monitoredResourceName": monitored_resource_name,
            "comparisonOperator": comparison_operator,
            "threshold": threshold,
            "evaluationPeriods": evaluation_periods,
            "datapointsToAlarm": datapoints_to_alarm,
            "treatMissingData": treat_missing_data,
            "contactProtocols": contact_protocols,
            "notificationTriggers": notification_triggers,
            "notificationEnabled": notification_enabled,
        },
    )


async def test(hub, ctx, alarm_name: str, state: str) -> Dict:
    r"""
    **Autogenerated function**

    Tests an alarm by displaying a banner on the Amazon Lightsail console. If a notification trigger is configured for the specified alarm, the test also sends a notification to the notification protocol (Email and/or SMS) configured for the alarm. An alarm is used to monitor a single metric for one of your resources. When a metric condition is met, the alarm can notify you by email, SMS text message, and a banner displayed on the Amazon Lightsail console. For more information, see Alarms in Amazon Lightsail.

    Args:
        alarm_name(str): The name of the alarm to test.
        state(str): The alarm state to test. An alarm has the following possible states that can be tested:    ALARM - The metric is outside of the defined threshold.    INSUFFICIENT_DATA - The alarm has just started, the metric is not available, or not enough data is available for the metric to determine the alarm state.    OK - The metric is within the defined threshold.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.alarm.test(ctx, alarm_name=value, state=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.alarm.test alarm_name=value, state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="test_alarm",
        op_kwargs={"alarmName": alarm_name, "state": state},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, engagement_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Incident Manager uses engagements to engage contacts and escalation plans during an incident. Use this command to describe the engagement that occurred during an incident.

    Args:
        engagement_id(str): The Amazon Resource Name (ARN) of the engagement you want the details of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.engagement.describe(ctx, engagement_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.engagement.describe engagement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="describe_engagement",
        op_kwargs={"EngagementId": engagement_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    incident_id: str = None,
    time_range_value: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all engagements that have happened in an incident.

    Args:
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of engagements per page of results. Defaults to None.
        incident_id(str, optional): The Amazon Resource Name (ARN) of the incident you're listing engagements for. Defaults to None.
        time_range_value(Dict, optional): The time range to lists engagements for an incident. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.engagement.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.engagement.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="list_engagements",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "IncidentId": incident_id,
            "TimeRangeValue": time_range_value,
        },
    )


async def start(
    hub,
    ctx,
    contact_id: str,
    sender: str,
    subject: str,
    content: str,
    public_subject: str = None,
    public_content: str = None,
    incident_id: str = None,
    idempotency_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an engagement to a contact or escalation plan. The engagement engages each contact specified in the incident.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact being engaged.
        sender(str): The user that started the engagement.
        subject(str): The secure subject of the message that was sent to the contact. Use this field for engagements to VOICE or EMAIL.
        content(str): The secure content of the message that was sent to the contact. Use this field for engagements to VOICE or EMAIL.
        public_subject(str, optional): The insecure subject of the message that was sent to the contact. Use this field for engagements to SMS. Defaults to None.
        public_content(str, optional): The insecure content of the message that was sent to the contact. Use this field for engagements to SMS. Defaults to None.
        incident_id(str, optional): The ARN of the incident that the engagement is part of. Defaults to None.
        idempotency_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.engagement.start(
                ctx, contact_id=value, sender=value, subject=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.engagement.start contact_id=value, sender=value, subject=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="start_engagement",
        op_kwargs={
            "ContactId": contact_id,
            "Sender": sender,
            "Subject": subject,
            "Content": content,
            "PublicSubject": public_subject,
            "PublicContent": public_content,
            "IncidentId": incident_id,
            "IdempotencyToken": idempotency_token,
        },
    )


async def stop(hub, ctx, engagement_id: str, reason: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops an engagement before it finishes the final stage of the escalation plan or engagement plan. Further contacts aren't engaged.

    Args:
        engagement_id(str): The Amazon Resource Name (ARN) of the engagement.
        reason(str, optional): The reason that you're stopping the engagement. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.engagement.stop(ctx, engagement_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.engagement.stop engagement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="stop_engagement",
        op_kwargs={"EngagementId": engagement_id, "Reason": reason},
    )
